Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(395)

Unified Diff: masters/master.client.webrtc.fyi/master_linux_cfg.py

Issue 1384273003: WebRTC: Bot for autorolling WebRTC+libjingle in Chromium DEPS. Base URL: https://chromium.googlesource.com/chromium/tools/build.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: masters/master.client.webrtc.fyi/master_linux_cfg.py
diff --git a/masters/master.client.webrtc.fyi/master_linux_cfg.py b/masters/master.client.webrtc.fyi/master_linux_cfg.py
index 29eae87c67a2b080118dd2ce7a1c7886a1749d46..644500750cafe8d5099e903584c3dd8d74ec9828 100644
--- a/masters/master.client.webrtc.fyi/master_linux_cfg.py
+++ b/masters/master.client.webrtc.fyi/master_linux_cfg.py
@@ -18,11 +18,14 @@ def Update(c):
'Linux64 Release (swarming)',
'Linux Tsan v2 (parallel)',
]),
# Run WebRTC DEPS roller every EMEA morning at 4am, 12pm and 8pm.
Nightly(
name='webrtc_deps',
branch=None,
- builderNames=['Auto-roll - WebRTC DEPS'],
+ builderNames=[
+ 'Auto-roll - Chromium DEPS',
+ 'Auto-roll - WebRTC DEPS',
+ ],
hour=[19,3,11],
),
])
@@ -37,6 +40,11 @@ def Update(c):
'slavebuilddir': 'linux_swarming',
},
{
+ 'name': 'Auto-roll - Chromium DEPS',
+ 'recipe': 'webrtc/auto_roll_chromium_deps',
+ 'slavebuilddir': 'linux_chromium_autoroll',
+ },
+ {
'name': 'Auto-roll - WebRTC DEPS',
'recipe': 'webrtc/auto_roll_webrtc_deps',
'slavebuilddir': 'linux_autoroll',
@@ -18,11 +18,14 @@ def Update(c):
'Linux Tsan v2 (parallel)',
]),
- # Run WebRTC DEPS roller every EMEA morning at 4am, 12pm and 8pm.
+ # Roll Chromium+WebRTC DEPS every EMEA morning at 4am, 12pm and 8pm.
Nightly(
name='webrtc_deps',
« no previous file with comments | « no previous file | masters/master.client.webrtc.fyi/slaves.cfg » ('j') | scripts/slave/recipes/webrtc/auto_roll_chromium_deps.py » ('J')

Powered by Google App Engine
This is Rietveld 408576698